import resolve from '@rollup/plugin-node-resolve';
import commonjs from '@rollup/plugin-commonjs';
import json from '@rollup/plugin-json';
import path from 'path';
import esbuild from 'rollup-plugin-esbuild';
import alias from '@rollup/plugin-alias';
import replace from '@rollup/plugin-replace';
import pkgs from './package.json' with {type: 'json'};
import typescript from '@rollup/plugin-typescript';

const isDev = process.env.NODE_ENV === 'development';
const input = isDev ? './src/dev.ts' : './src/index.ts';
console.log('isDev:', isDev, 'input:', input);
/**
 * @type {import('rollup').RollupOptions}
 */
const config = {
  input,
  output: {
    dir: './dist',
    entryFileNames: 'app.mjs',
    chunkFileNames: '[name]-[hash].mjs',
    format: 'esm',
  },
  plugins: [
    replace({
      preventAssignment: true, // 防止意外赋值
      DEV_SERVER: JSON.stringify(isDev), // 替换 process.env.NODE_ENV
      VERSION: JSON.stringify(pkgs.version),
    }),
    alias({
      // only esbuild needs to be configured
      entries: [
        { find: '@', replacement: path.resolve('src') }, // 配置 @ 为 src 目录
        // { find: '@kevisual/code-center-module', replacement: path.resolve('node_modules/@kevisual/code-center-module') },
      ],
    }),
    resolve({
      preferBuiltins: true,
    }),
    commonjs(),
    esbuild({
      target: 'node22', //
      minify: false, // 启用代码压缩
      tsconfig: 'tsconfig.json',
      include: [
        "src/**/*.ts",
      ]
    }),
    json(),
  ],
  external: [
    /@kevisual\/router(\/.*)?/, //, // 路由
    /@kevisual\/use-config(\/.*)?/, //
    /@kevisual\/code-center-module(\/.*)?/, //
    
    'sequelize', // 数据库 orm
    'ioredis', // redis
    'pg', // pg
  ],
};
export default config;
