import { query } from '../../modules/query'

import { message } from 'antd'
import { create } from 'zustand'
import { TencentCaptcha } from '@/modules/tencent-captcha'

type UserStore = {
  isAuthenticated: boolean
  qrCodeUrl: string
  checkAuthStatus: () => void
  getCode: (phone: string, captcha: TencentCaptcha) => void
  login: (phone: string, code: string) => void
  updateUser: (data: any) => void
  getUpdateUser: () => void
  data: any
  setData: (data: any) => void
}
export const useUserStore = create<UserStore>((set) => ({
  isAuthenticated: false,
  qrCodeUrl: '',
  checkAuthStatus: () => {
    //
  },
  getCode: async (phone, captcha) => {
    const res = await query.post({
      path: 'sms',
      key: 'send',
      data: {
        phone,
        captcha
      }
    })
    if (res.code === 200) {
      // do something
      message.success('验证码发送成功')
    } else {
      message.error(res.message || '验证码发送失败')
    }
  },
  login: async (phone, code) => {
    const res = await query.post({
      path: 'sms',
      key: 'login',
      data: {
        phone,
        code
      }
    })
    console.log(res)
    if (res.code === 200) {
      message.success('登录成功')
      const data = res.data
      localStorage.setItem('token', data.token)
      localStorage.setItem('expireTime', data.expireTime)
      set({ isAuthenticated: true })
      const href = location.href
      const url = new URL(href)
      const redirect = url.searchParams.get('redirect')
      if (redirect) {
        const href = decodeURIComponent(redirect)
        window.open(href, '_self')
        return
      }
      if (data.isNew) {
        location.href = '/user/info'
      } else {
        location.href = '/workspace'
      }
    } else {
      message.error(res.message || '登录失败')
    }
  },
  updateUser: async (data) => {
    const res = await query.post({
      path: 'user',
      key: 'updateInfo',
      data
    })
    if (res.code === 200) {
      message.success('更新成功')
      setTimeout(() => {
        location.href = '/workspace'
      }, 1000)
    } else {
      message.error(res.message || '更新失败')
    }
  },
  getUpdateUser: async () => {
    const res = await query.post({
      path: 'user',
      key: 'getUpdateInfo'
    })
    if (res.code === 200) {
      set({ data: res.data })
    } else {
      message.error(res.message || '获取用户信息失败')
    }
  },
  data: {},
  setData: (data) => set({ data })
}))
